@@ -1,6 +1,6 @@
 ## Domain Registry Interface, AFNIC WS Message
 ##
-## Copyright (c) 2005,2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,24 +10,27 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Protocol::AFNIC::WS::Message;
 
-use utf8;
 use strict;
-use warnings;
 
 use Net::DRI::Protocol::ResultStatus;
 
 use base qw(Class::Accessor::Chained::Fast Net::DRI::Protocol::Message);
 __PACKAGE__->mk_accessors(qw(version service method params result errcode));
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::AFNIC::WS::Message - AFNIC Web Services Message for Net::DRI
+Net::DRI::Protocol::AFNIC::WS::Message - AFNIC WebService Message for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -51,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,11 +66,13 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-####################################################################################################
+our %CODES; ## defined at bottom
 
 sub new
 {
- my $class=shift;
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+
  my $self={errcode => undef};
  bless($self,$class);
 
@@ -82,18 +87,7 @@ sub new
  return $self;
 }
 
-sub as_string
-{
- my ($self)=@_;
- my @p=@{$self->params()};
- my @pr;
- foreach my $i (0..$#p)
- {
-  push @pr,sprintf 'PARAM%d=%s',$i+1,$p[$i];
- }
-
- return sprintf "SERVICE=%s\nMETHOD=%s\n%s\n",$self->service(),$self->method(),join("\n",@pr);
-}
+sub as_string { return undef; }
 
 sub parse
 {
@@ -106,42 +100,44 @@ sub parse
 
  ## Warning: when we handle multiple web services, we will need a way to retrieve the method name called,
  ## to find the correct errcode, as it will obviously not be done the same way accross all services.
- return;
 }
 
-## We handle all non free cases as errors, even if we should not
-sub is_success
-{
- my $self=shift;
- my $r=$self->result();
- my $code=$self->errcode();
-
- return 1 if ($r->{free});
- return 0;
-}
+sub is_success { return 0; } ## because, it is either an error, or the domain does not exist (which is a 2xxx in EPP)
 
 sub result_status
 {
  my $self=shift;
  my $r=$self->result();
-
- return Net::DRI::Protocol::ResultStatus->new_success($r->{message}) if $r->{free};
-
- my %codes=( 0   => 2400, # problème de connexion à la base de données => Command failed
-             1   => 2302, # le nom de domaine est déjà enregistré => Object exists
-             2   => 2308, # un nom de domaine est déjà enregistré à l'identique dans l'une des extensions du domaine public => Data management policy violation
-             4   => 2304, # une opération est en cours pour ce nom de domaine => Object status prohibits operation
-             5   => 2308, # nom de domaine interdit (termes fondamentaux) => Data management policy violation
-             51  => 2308, # nom de domaine réservé pour les communes => Data management policy violation
-             100 => 2005, # mauvaise syntaxe du nom de domaine => Parameter value syntax error
-           );
-
- my $code=$self->errcode();
- my $eppcode=(defined $code && exists $codes{$code})? $codes{$code} : 'COMMAND_FAILED';
- return Net::DRI::Protocol::ResultStatus->new('afnic_ws_check_domain',$code,$eppcode,$self->is_success(),$r->{message});
+ return Net::DRI::Protocol::ResultStatus->new_error(2303,$r->{message}) if ($r->{free});
+ return Net::DRI::Protocol::ResultStatus->new('afnic_ws_check_domain',$self->errcode(),\%CODES,$self->is_success(),$r->{message});
  ## Warning: when we handle multiple web services, we will need a way to retrieve the method name called,
- ## to find the correct key of the hash (and special case of free <=> 2303)
+ ## to find the correct key of the %CODES hash (and special case of free <=> 2303)
 }
 
-####################################################################################################
+########################################################################
+
+sub get_name_from_message
+{
+ my ($self)=@_;
+ my $c=$self->method();
+ my $rp=$self->params();
+
+ return $rp->[0] if ($c eq 'check_domain');
+}
+
+#############################################################################################
+
+
+%CODES=( 'afnic_ws_check_domain' =>
+          {
+           0   => 2400, # problme de connexion  la base de donnes => Command failed
+           1   => 2302, # le nom de domaine est dj enregistr => Object exists
+           2   => 2308, # refus car un nom de domaine quivalent existe dj sous .fr ou sous .re => Data management policy violation
+           4   => 2304, # une opration est en cours pour ce nom de domaine => Object status prohibits operation
+           5   => 2308, # nom de domaine interdit (faisant partie de la liste des termes fondamentaux) => Data management policy violation
+           100 => 2005, # mauvaise syntaxe du nom de domaine => Parameter value syntax error
+          },
+       );
+
+########################################################################
 1;
