@@ -1,6 +1,6 @@
 ## Domain Registry Interface, SOAP Transport (HTTP/HTTPS)
 ##
-## Copyright (c) 2005,2009-2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,19 +10,22 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Transport::SOAP;
 
-use strict;
-use warnings;
-
 use base qw(Net::DRI::Transport);
+use strict;
 
 use Net::DRI::Exception;
 
 use SOAP::Lite;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -66,7 +69,7 @@ C<ssl_ca_file> is a string giving the local path to the CA certificate file, if
 =item * only for SOAP over HTTP/HTTPS
 
 =item * only one CA certificate can be used in each given instance of Net::DRI 
-(because it is given through %ENV)
+(because is given through %ENV)
 
 =back
 
@@ -88,7 +91,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2009-2011,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -100,25 +103,29 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-####################################################################################################
-
+#######################################################################################
 sub new
 {
- my ($class,$ctx,$rp)=@_;
- my %opts=%$rp;
- my $self=$class->SUPER::new($ctx,\%opts); ## We are now officially a Net::DRI::Transport instance
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+
+ my $drd=shift;
+
+ my %opts=(@_==1 && ref($_[0]))? %{$_[0]} : @_;
+ my $self=$class->SUPER::new(\%opts); ## We are now officially a Net::DRI::Transport instance
  $self->has_state(0);
  $self->is_sync(1);
  $self->name('soap');
- $self->version('0.1');
+ $self->version($VERSION);
 
  my %t;
 
- Net::DRI::Exception::usererr_insufficient_parameters('proxy_url must be defined') unless (exists($opts{proxy_url}));
- Net::DRI::Exception::usererr_invalid_parameters('proxy_url must be http:// or https://') unless ($opts{proxy_url}=~m!^https?://!);
- Net::DRI::Exception::usererr_insufficient_parameters('service_wsdl') unless (exists($opts{service_wsdl}));
- Net::DRI::Exception::usererr_invalid_parameters('service_wsdl must be a ref hash') unless (ref($opts{service_wsdl}) eq 'HASH'); ## Name (without .wsdl),ex: Domain => Path to corresponding wsdl file
+ Net::DRI::Exception::usererr_insufficient_parameters("proxy_url must be defined") unless (exists($opts{proxy_url}));
+ Net::DRI::Exception::usererr_invalid_parameters("proxy_url must be http:// or https://") unless ($opts{proxy_url}=~m!^https?://!);
 
+ Net::DRI::Exception::usererr_insufficient_parameters("service_wsdl") unless (exists($opts{service_wsdl}));
+ Net::DRI::Exception::usererr_invalid_parameters("service_wsdl must be a ref hash") unless (ref($opts{service_wsdl}) eq 'HASH'); ## Name (without .wsdl),ex: Domain => Path to corresponding wsdl file
+ 
  my $service=SOAP::Lite->on_fault(\&soap_fault);
  my %st;
 
@@ -126,7 +133,6 @@ sub new
  {
   my $go=$service->service($v);
   my $t=$go->transport();
-  $t->agent(sprintf('Net::DRI/%s',$Net::DRI::VERSION).$t->agent());
   if ($self->timeout())
   {
    $t->proxy($opts{proxy_url},timeout => $self->timeout());
@@ -145,26 +151,26 @@ sub new
 
  if (exists($opts{ssl_ca_file}) && (-s $opts{ssl_ca_file}))
  {
-  ## How to handle multiple SOAP instances in the same process ??
-  $ENV{HTTPS_CA_FILE}=$opts{ssl_ca_file}; ## no critic (Variables::RequireLocalizedPunctuationVars)
+  $ENV{HTTPS_CA_FILE}=$opts{ssl_ca_file}; ## How to handle multiple SOAP instances in the same process ??
  }
-
+ 
  $t{soap}=$service;
  $self->{transport}=\%t;
+ bless($self,$class);
  return $self;
 }
 
-sub soap_fault ## no critic (Subroutines::RequireFinalReturn)
+sub soap_fault
 {
  my($soap,$res)=@_; 
- my $msg=ref $res ? $res->faultstring() : $soap->transport()->status();
- Net::DRI::Exception->die(1,'transport/soap',7,'SOAP fault: '.$msg);
+ my $msg=ref($res)? $res->faultstring : $soap->transport->status;
+ Net::DRI::Exception->die(1,'transport/soap',7,"SOAP fault: $msg");
 }
 
-sub send ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub send
 {
- my ($self,$ctx,$tosend)=@_;
- return $self->SUPER::send($ctx,$tosend,\&_soap_send,sub {});
+ my ($self,$tosend)=@_;
+ $self->SUPER::send($tosend,\&_soap_send,sub {});
 }
 
 sub _soap_send
@@ -185,8 +191,8 @@ sub _soap_send
 
 sub receive
 {
- my ($self,$ctx,$count)=@_;
- return $self->SUPER::receive($ctx,\&_soap_receive);
+ my $self=shift;
+ return $self->SUPER::receive(\&_soap_receive);
 }
 
 sub _soap_receive
@@ -200,5 +206,5 @@ sub _soap_receive
  return $r; ## will we need one day access to $so ?
 }
 
-####################################################################################################
+#####################################################################################################
 1;
